@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service client paginators.
 
-[Open documentation](./paginators.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html)
 
 Usage::
 
@@ -30,16 +30,17 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
     def paginate(
         self,
+        *,
         Filters: List[FilterTypeDef] = None,
         SortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
-        [Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
